@@ -16,8 +16,8 @@
  * 
  */
 
-#ifndef _BMC_DEVICE_H
-#define _BMC_DEVICE_H
+#ifndef BMC_DEVICE_H
+#define BMC_DEVICE_H
 
 #include <freeipmi/freeipmi.h>
 
@@ -39,16 +39,17 @@ enum bmc_device_argp_option_keys
     GET_SEL_TIME_KEY = 170,
     SET_SEL_TIME_KEY = 171,
     PLATFORM_EVENT_KEY = 172,
-    GET_MCA_AUXILIARY_LOG_STATUS_KEY = 173,
-    GET_SSIF_INTERFACE_CAPABILITIES_KEY = 174,
-    GET_KCS_INTERFACE_CAPABILITIES_KEY = 175,
-    GET_BT_INTERFACE_CAPABILITIES_KEY = 176,
-    GET_BMC_GLOBAL_ENABLES_KEY = 177,
-    SET_SYSTEM_FIRMWARE_VERSION_KEY=178,
-    SET_SYSTEM_NAME_KEY=179,
-    SET_PRIMARY_OPERATING_SYSTEM_NAME_KEY=180,
-    SET_OPERATING_SYSTEM_NAME_KEY=181,
-    VERBOSE_KEY = 182,
+    SET_SENSOR_READING_AND_EVENT_STATUS_KEY = 173,
+    GET_MCA_AUXILIARY_LOG_STATUS_KEY = 174,
+    GET_SSIF_INTERFACE_CAPABILITIES_KEY = 175,
+    GET_KCS_INTERFACE_CAPABILITIES_KEY = 176,
+    GET_BT_INTERFACE_CAPABILITIES_KEY = 177,
+    GET_BMC_GLOBAL_ENABLES_KEY = 178,
+    SET_SYSTEM_FIRMWARE_VERSION_KEY = 179,
+    SET_SYSTEM_NAME_KEY = 180, 
+    SET_PRIMARY_OPERATING_SYSTEM_NAME_KEY = 181,
+    SET_OPERATING_SYSTEM_NAME_KEY = 182,
+    VERBOSE_KEY = 183,
   };
 
 enum bmc_device_set_acpi_power_state_options
@@ -67,9 +68,7 @@ struct bmc_device_set_acpi_power_state
 
 struct bmc_device_arguments
 {
-  struct common_cmd_args common;
-  struct sdr_cmd_args sdr;
-  struct hostrange_cmd_args hostrange;
+  struct common_cmd_args common_args;
   int cold_reset;
   int warm_reset;
   int get_self_test_results;
@@ -88,6 +87,8 @@ struct bmc_device_arguments
   char *set_sel_time_arg;
   int platform_event;
   char *platform_event_arg;
+  int set_sensor_reading_and_event_status;
+  char *set_sensor_reading_and_event_status_arg;
   int get_mca_auxiliary_log_status;
   int get_ssif_interface_capabilities;
   int get_kcs_interface_capabilities;
@@ -116,8 +117,7 @@ typedef struct bmc_device_state_data
   ipmi_ctx_t ipmi_ctx;
   pstdout_state_t pstate;
   char *hostname;
-  ipmi_sdr_cache_ctx_t sdr_cache_ctx;
-  ipmi_sdr_parse_ctx_t sdr_parse_ctx;
+  ipmi_sdr_ctx_t sdr_ctx;
 } bmc_device_state_data_t;
 
-#endif
+#endif /* BMC_DEVICE_H */
