@@ -16,31 +16,18 @@
  * 
  */
 
-#ifndef _TOOL_COMMON_H
-#define _TOOL_COMMON_H
+#ifndef TOOL_COMMON_H
+#define TOOL_COMMON_H
 
 #include <stdint.h>
 #include <freeipmi/freeipmi.h>
 
 #include "tool-cmdline-common.h"
-#include "parse-common.h"
-
-#define IPMI_OPEN_ERRMSGLEN 1024
-
-int ipmi_is_root ();
-
-void ipmi_disable_coredump (void);
+#include "pstdout.h"
 
 ipmi_ctx_t ipmi_open (const char *progname,
                       const char *hostname,
-                      struct common_cmd_args *cmd_args,
-                      char *errmsg,
-                      unsigned int errmsglen);
+                      struct common_cmd_args *common_args,
+		      pstdout_state_t pstate);
 
-/* Check if kg len is decent */
-int check_kg_len (const char *in);
-
-/* Turn a 20-byte binary k_g key into an output string */
-char *format_kg (char *out, unsigned int outlen, const void *k_g);
-
-#endif
+#endif /* TOOL_COMMON_H */
