@@ -39,15 +39,6 @@
 
 #define IPMI_OEM_SUPERMICRO_STRING_MAX 128
 
-#define IPMI_OEM_SUPERMICRO_SUB_COMMAND_BMC_SERVICES 0xF0
-
-#define IPMI_OEM_SUPERMICRO_BMC_SERVICES_ACTION_DISABLE  0x00
-#define IPMI_OEM_SUPERMICRO_BMC_SERVICES_ACTION_ENABLE   0x01
-#define IPMI_OEM_SUPERMICRO_BMC_SERVICES_ACTION_STATUS   0x02
-
-#define IPMI_OEM_SUPERMICRO_BMC_SERVICES_STATUS_DISABLED 0x00
-#define IPMI_OEM_SUPERMICRO_BMC_SERVICES_STATUS_ENABLED  0x01
-
 int
 ipmi_oem_supermicro_extra_firmware_info (ipmi_oem_state_data_t *state_data)
 {
