@@ -16,8 +16,8 @@
  * 
  */
 
-#ifndef _IPMI_MESSAGING_SUPPORT_CMDS_API_H
-#define _IPMI_MESSAGING_SUPPORT_CMDS_API_H
+#ifndef IPMI_MESSAGING_SUPPORT_CMDS_API_H
+#define IPMI_MESSAGING_SUPPORT_CMDS_API_H
 
 #ifdef __cplusplus
 extern "C" {
@@ -327,6 +327,4 @@ int ipmi_cmd_set_user_password (ipmi_ctx_t ctx,
 }
 #endif
 
-#endif /* _IPMI_MESSAGING_SUPPORT_CMDS_API_H */
-
-
+#endif /* IPMI_MESSAGING_SUPPORT_CMDS_API_H */
