@@ -65,6 +65,16 @@ extern "C" {
 #define IPMI_SENSOR_TYPE_OEM_FUJITSU_EVENT                      0xEE // Reserved
 #define IPMI_SENSOR_TYPE_OEM_FUJITSU_CONFIG_BACKUP              0xEF
 
+/*******************************************
+ * HP                                      *
+ *******************************************/
+
+/*
+ * HP Proliant DL160 G8
+ */
+
+#define IPMI_SENSOR_TYPE_OEM_HP_LED                             0xC0
+
 /*******************************************
  * Intel                                   *
  *******************************************/
@@ -141,6 +151,7 @@ extern "C" {
  * Supermicro X9DRi-F (X9DRI_F)
  * Supermicro X9DRI-LN4F+ (X9DRI_LN4F_PLUS)
  * Supermicro X9SPU-F-O (X9SPU-F-O)
+ * Supermicro X9SCM-iiF (X9SCM_IIF)
  */
 /* achu: not official names, named based on use context */
 #define IPMI_SENSOR_TYPE_OEM_SUPERMICRO_CPU_TEMP 0xC0 
