@@ -142,6 +142,128 @@ ipmi_get_oem_sensor_type_string (uint8_t sensor_type,
   return (NULL);
 }
 
+int
+ipmi_sensor_units_string (uint8_t sensor_units_percentage,
+                          uint8_t sensor_units_modifier,
+                          uint8_t sensor_units_rate,
+                          uint8_t sensor_base_unit_type,
+                          uint8_t sensor_modifier_unit_type,
+                          char *buf,
+                          unsigned int buflen,
+                          unsigned int abbreviated_units_flag)
+{
+  const char **sensor_units = NULL;
+  int offset = 0;
+  int rv = -1;
+
+  if (!IPMI_SDR_PERCENTAGE_VALID(sensor_units_percentage)
+      || !IPMI_SDR_MODIFIER_UNIT_VALID(sensor_units_modifier)
+      || !IPMI_SENSOR_RATE_UNIT_VALID(sensor_units_rate)
+      || !IPMI_SENSOR_UNIT_VALID(sensor_base_unit_type)
+      || !IPMI_SENSOR_UNIT_VALID(sensor_modifier_unit_type)
+      || !buf
+      || !buflen)
+    {
+      SET_ERRNO (EINVAL);
+      return (-1);
+    }
+
+  /* achu: I assume this must be the case */
+  if (sensor_units_modifier != IPMI_SDR_MODIFIER_UNIT_NONE
+      && sensor_units_rate != IPMI_SENSOR_RATE_UNIT_NONE)
+    {
+      SET_ERRNO (EINVAL);
+      return (-1);
+    }
+
+  /* achu: I don't understand percentages exactly, I'll just
+   * assume it's a percent sign infront of everything else.
+   */
+  if (sensor_units_percentage == IPMI_SDR_PERCENTAGE_YES)
+    {
+      /* Special case, nothing to add to the end of the percentage,
+       * and the base unit is unspecified, just output '%' only.
+       */
+      if (sensor_units_modifier == IPMI_SDR_MODIFIER_UNIT_NONE
+	  && sensor_units_rate == IPMI_SENSOR_RATE_UNIT_NONE
+	  && sensor_base_unit_type == IPMI_SENSOR_UNIT_UNSPECIFIED)
+	{
+	  rv = snprintf (buf,
+			 buflen,
+			 "%%");
+	  return (rv);
+	}
+      else
+	offset = snprintf (buf,
+			   buflen,
+			   "%% ");
+    }
+
+  if (abbreviated_units_flag)
+    sensor_units = (const char **)ipmi_sensor_units_abbreviated;
+  else
+    sensor_units = (const char **)ipmi_sensor_units;
+
+  if (sensor_units_modifier == IPMI_SDR_MODIFIER_UNIT_NONE
+      && sensor_units_rate == IPMI_SENSOR_RATE_UNIT_NONE)
+    {
+      rv = snprintf (buf + offset,
+                     buflen,
+                     "%s",
+                     sensor_units[sensor_base_unit_type]);
+      return (rv);
+    }
+  
+  if (sensor_units_rate != IPMI_SENSOR_RATE_UNIT_NONE)
+    {
+      /* Special case, RPM is inheritly per minute
+       *
+       * If vendor specifies a rate other than "per minute", that's
+       * probably a bug in their SDR.
+       */
+      if (sensor_base_unit_type == IPMI_SENSOR_UNIT_RPM
+          && sensor_units_rate == IPMI_SENSOR_RATE_UNIT_PER_MINUTE)
+        rv = snprintf (buf + offset,
+                       buflen,
+                       "%s",
+                       sensor_units[sensor_base_unit_type]);
+      else
+        rv = snprintf (buf + offset,
+                       buflen,
+                       "%s %s",
+                       sensor_units[sensor_base_unit_type],
+                       ipmi_sensor_rate_units[sensor_units_rate]);
+      return (rv);
+    }
+  
+  /* else sensor_units_modifier != IPMI_SDR_MODIFIER_UNIT_NONE */
+
+  /* achu: corner case, some vendors messed up */
+  if (sensor_modifier_unit_type == IPMI_SENSOR_UNIT_UNSPECIFIED)
+    {
+      rv = snprintf (buf + offset,
+		     buflen,
+		     "%s",
+		     sensor_units[sensor_base_unit_type]);
+    }
+  else
+    {
+      if (sensor_units_modifier == IPMI_SDR_MODIFIER_UNIT_DIVIDE)
+	rv = snprintf (buf + offset,
+		       buflen,
+		       "%s / %s",
+		       sensor_units[sensor_base_unit_type],
+		       sensor_units[sensor_modifier_unit_type]);
+      else
+	rv = snprintf (buf + offset,
+		       buflen,
+		       "%s * %s",
+		       sensor_units[sensor_base_unit_type],
+		       sensor_units[sensor_modifier_unit_type]);
+    }
+
+  return (rv);
+}
 
 int
 ipmi_sensor_decode_value (int8_t r_exponent,
@@ -178,31 +300,43 @@ ipmi_sensor_decode_value (int8_t r_exponent,
   dval += (b * pow (10, b_exponent));
   dval *= pow (10, r_exponent);
 
-  if (linearization == IPMI_SDR_LINEARIZATION_LN)
-    dval = log (dval);
-  else if (linearization == IPMI_SDR_LINEARIZATION_LOG10)
-    dval = log10 (dval);
-  else if (linearization == IPMI_SDR_LINEARIZATION_LOG2)
-    dval = log2 (dval);
-  else if (linearization == IPMI_SDR_LINEARIZATION_E)
-    dval = exp (dval);
-  else if (linearization == IPMI_SDR_LINEARIZATION_EXP10)
-    dval = exp10 (dval);
-  else if (linearization == IPMI_SDR_LINEARIZATION_EXP2)
-    dval = exp2 (dval);
-  else if (linearization == IPMI_SDR_LINEARIZATION_INVERSE)
+  switch (linearization)
     {
+    case IPMI_SDR_LINEARIZATION_LN:
+      dval = log (dval);
+      break;
+    case IPMI_SDR_LINEARIZATION_LOG10:
+      dval = log10 (dval);
+      break;
+    case IPMI_SDR_LINEARIZATION_LOG2:
+      dval = log2 (dval);
+      break;
+    case IPMI_SDR_LINEARIZATION_E:
+      dval = exp (dval);
+      break;
+    case IPMI_SDR_LINEARIZATION_EXP10:
+      dval = exp10 (dval);
+      break;
+    case IPMI_SDR_LINEARIZATION_EXP2:
+      dval = exp2 (dval);
+      break;
+    case IPMI_SDR_LINEARIZATION_INVERSE:
       if (dval != 0.0)
-        dval = 1.0 / dval;
+	dval = 1.0 / dval;
+      break;
+    case IPMI_SDR_LINEARIZATION_SQR:
+      dval = pow (dval, 2.0);
+      break;
+    case IPMI_SDR_LINEARIZATION_CUBE:
+      dval = pow (dval, 3.0);
+      break;
+    case IPMI_SDR_LINEARIZATION_SQRT:
+      dval = sqrt (dval);
+      break;
+    case IPMI_SDR_LINEARIZATION_CUBERT:
+      dval = cbrt (dval);
+      break;
     }
-  else if (linearization == IPMI_SDR_LINEARIZATION_SQR)
-    dval = pow (dval, 2.0);
-  else if (linearization == IPMI_SDR_LINEARIZATION_CUBE)
-    dval = pow (dval, 3.0);
-  else if (linearization == IPMI_SDR_LINEARIZATION_SQRT)
-    dval = sqrt (dval);
-  else if (linearization == IPMI_SDR_LINEARIZATION_CUBERT)
-    dval = cbrt (dval);
 
   *value = dval;
   return (0);
@@ -243,31 +377,43 @@ ipmi_sensor_decode_raw_value (int8_t r_exponent,
    * Folks online suggest just using exp(1.0) in its place.  Sounds
    * good to me.
    */
-  if (linearization == IPMI_SDR_LINEARIZATION_LN)
-    dval = exp (dval);
-  else if (linearization == IPMI_SDR_LINEARIZATION_LOG10)
-    dval = exp10 (dval);
-  else if (linearization == IPMI_SDR_LINEARIZATION_LOG2)
-    dval = exp2 (dval);
-  else if (linearization == IPMI_SDR_LINEARIZATION_E)
-    dval = (log (dval)/log (exp (1.0)));
-  else if (linearization == IPMI_SDR_LINEARIZATION_EXP10)
-    dval = (log (dval)/log (10));
-  else if (linearization == IPMI_SDR_LINEARIZATION_EXP2)
-    dval = (log (dval)/log (2));
-  else if (linearization == IPMI_SDR_LINEARIZATION_INVERSE)
+  switch (linearization)
     {
+    case IPMI_SDR_LINEARIZATION_LN:
+      dval = exp (dval);
+      break;
+    case IPMI_SDR_LINEARIZATION_LOG10:
+      dval = exp10 (dval);
+      break;
+    case IPMI_SDR_LINEARIZATION_LOG2:
+      dval = exp2 (dval);
+      break;
+    case IPMI_SDR_LINEARIZATION_E:
+      dval = (log (dval)/log (exp (1.0)));
+      break;
+    case IPMI_SDR_LINEARIZATION_EXP10:
+      dval = (log (dval)/log (10));
+      break;
+    case IPMI_SDR_LINEARIZATION_EXP2:
+      dval = (log (dval)/log (2));
+      break;
+    case IPMI_SDR_LINEARIZATION_INVERSE:
       if (dval != 0.0)
         dval = 1.0 / dval;
+      break;
+    case IPMI_SDR_LINEARIZATION_SQR:
+      dval = sqrt (dval);
+      break;
+    case IPMI_SDR_LINEARIZATION_CUBE:
+      dval = cbrt (dval);
+      break;
+    case IPMI_SDR_LINEARIZATION_SQRT:
+      dval = pow (dval, 2.0);
+      break;
+    case IPMI_SDR_LINEARIZATION_CUBERT:
+      dval = pow (dval, 3.0);
+      break;
     }
-  else if (linearization == IPMI_SDR_LINEARIZATION_SQR)
-    dval = sqrt (dval);
-  else if (linearization == IPMI_SDR_LINEARIZATION_CUBE)
-    dval = cbrt (dval);
-  else if (linearization == IPMI_SDR_LINEARIZATION_SQRT)
-    dval = pow (dval, 2.0);
-  else if (linearization == IPMI_SDR_LINEARIZATION_CUBERT)
-    dval = pow (dval, 3.0);
 
   dval = (dval / pow (10, r_exponent));
   dval = (dval - (b * pow (10, b_exponent)));
@@ -322,31 +468,43 @@ ipmi_sensor_decode_tolerance (int8_t r_exponent,
   dval /= 2.0;
   dval += (dval * pow (10, r_exponent));
 
-  if (linearization == IPMI_SDR_LINEARIZATION_LN)
-    dval = log (dval);
-  else if (linearization == IPMI_SDR_LINEARIZATION_LOG10)
-    dval = log10 (dval);
-  else if (linearization == IPMI_SDR_LINEARIZATION_LOG2)
-    dval = log2 (dval);
-  else if (linearization == IPMI_SDR_LINEARIZATION_E)
-    dval = exp (dval);
-  else if (linearization == IPMI_SDR_LINEARIZATION_EXP10)
-    dval = exp10 (dval);
-  else if (linearization == IPMI_SDR_LINEARIZATION_EXP2)
-    dval = exp2 (dval);
-  else if (linearization == IPMI_SDR_LINEARIZATION_INVERSE)
+  switch (linearization)
     {
+    case IPMI_SDR_LINEARIZATION_LN:
+      dval = log (dval);
+      break;
+    case IPMI_SDR_LINEARIZATION_LOG10:
+      dval = log10 (dval);
+      break;
+    case IPMI_SDR_LINEARIZATION_LOG2:
+      dval = log2 (dval);
+      break;
+    case IPMI_SDR_LINEARIZATION_E:
+      dval = exp (dval);
+      break;
+    case IPMI_SDR_LINEARIZATION_EXP10:
+      dval = exp10 (dval);
+      break;
+    case IPMI_SDR_LINEARIZATION_EXP2:
+      dval = exp2 (dval);
+      break;
+    case IPMI_SDR_LINEARIZATION_INVERSE:
       if (dval != 0.0)
-        dval = 1.0 / dval;
+	dval = 1.0 / dval;
+      break;
+    case IPMI_SDR_LINEARIZATION_SQR:
+      dval = pow (dval, 2.0);
+      break;
+    case IPMI_SDR_LINEARIZATION_CUBE:
+      dval = pow (dval, 3.0);
+      break;
+    case IPMI_SDR_LINEARIZATION_SQRT:
+      dval = sqrt (dval);
+      break;
+    case IPMI_SDR_LINEARIZATION_CUBERT:
+      dval = cbrt (dval);
+      break;
     }
-  else if (linearization == IPMI_SDR_LINEARIZATION_SQR)
-    dval = pow (dval, 2.0);
-  else if (linearization == IPMI_SDR_LINEARIZATION_CUBE)
-    dval = pow (dval, 3.0);
-  else if (linearization == IPMI_SDR_LINEARIZATION_SQRT)
-    dval = sqrt (dval);
-  else if (linearization == IPMI_SDR_LINEARIZATION_CUBERT)
-    dval = cbrt (dval);
 
   *value = dval;
   return (0);
